@@ -1,6 +1,6 @@
 =head1 NAME
 
-Lingua::EN::AddressParse - manipulate geographical addresses
+Lingua::EN::AddressParse - extract components of a street address, presented as a text string
 
 =head1 SYNOPSIS
 
@@ -8,7 +8,7 @@ Lingua::EN::AddressParse - manipulate geographical addresses
 
     my %args =
     (
-      country     => 'Australia',
+      country     => 'US',
       auto_clean  => 1,
       force_case  => 1,
       abbreviate_subcountry => 0,
@@ -17,19 +17,35 @@ Lingua::EN::AddressParse - manipulate geographical addresses
     );
 
     my $address = Lingua::EN::AddressParse->new(%args);
-    $error = $address->parse(
-       "UNIT 2A 14-16 OLD SOUTH HEAD ST ST JOHNS WOOD NSW 2021 AUSTRALIA : HOLD MAIL");
-
-    %my_address = $address->components;
-    print $my_address{sub_property_identifier}; # UNIT 2A
-    print $my_address{property_identifier};     # 14-16
-
-    print $my_address{suburb};                  # ST JOHNS WOOD
-
-    %my_formatted_address = $address->components;
-    print $my_formatted_address{street_name};        # Old South Head
-    print $my_formatted_address{street_type};   # St
+    $error = $address->parse("40 1/2 N OLD MASSACHUSETTS AVE APT 3B Washington Valley Washington 98100: HOLD MAIL");
+       
+    print $address->report;       
+       
+        Country address format  'US'
+        Address type            'suburban'
+        Non matching part       'HOLD MAIL '
+        Error                   '1'
+        Error descriptions      'non matching section : HOLD MAIL '
+        Warning                 '1'
+        Warning description     ''
+        Case all                '40 1/2 N Old Massachusetts Ave Apt 3B Washington Valley WA 98100'
+        COMPONENTS              ''
+        base_street_name        'Old Massachusetts'
+        post_code               '98100'
+        property_identifier     '40 1/2'
+        street_direction_prefix 'N'
+        street_name             'N Old Massachusetts'
+        street_type             'Ave'
+        sub_property_identifier '3B'
+        sub_property_type       'Apt'
+        subcountry              'WA'
+        suburb                  'Washington Valley'       
 
+    %address_components = $address->components;
+    print $address_components{sub_property_type};       # APT
+    print $address_components{sub_property_identifier}; # 3B
+    print $address_components{property_identifier};     # 40 1/2
+   
     %address_properties = $address->properties;
     print $address_properties{type};            # suburban
     print $address_properties{non_matching};    # : HOLD MAIL
@@ -42,11 +58,6 @@ Lingua::EN::AddressParse - manipulate geographical addresses
 This module takes as input a suburban, rural or postal address in free format
 text such as,
 
-    2A LOW ST KEW NSW 2123
-    12/3-5 AUBREY ST MOUNT VICTORIA VICTORIA 3133
-    "OLD REGRET" WENTWORTH FALLS NSW 2782 AUSTRALIA
-    GPO Box K318, HAYMARKET, NSW 2000
-
     3080 28TH AVE N ST PETERSBURG, FL 33713-3810
     12 1st Avenue N Suite # 2 Somewhere CA 12345 USA
     C/O JOHN, KENNETH JR POA 744 WIND RIVER DR SYLVANIA, OH 43560-4317
@@ -54,6 +65,12 @@ text such as,
     9 Church Street, Abertillery, Mid Glamorgan NP13 1DA
     27 Bury Street, Abingdon, Oxfordshire OX14 3QT
 
+    2A LOW ST KEW NSW 2123
+    12/3-5 AUBREY ST MOUNT VICTORIA VICTORIA 3133
+    "OLD REGRET" WENTWORTH FALLS NSW 2782 AUSTRALIA
+    GPO Box K318, HAYMARKET, NSW 2000
+
+ 
 and attempts to parse it. If successful, the address is broken
 down into it's components and useful functions can be performed such as :
 
@@ -67,7 +84,7 @@ of bad characters, or extracting any portion that was parsed and the portion
 that failed.
 
 This module can be used for analysing and improving the quality of
-lists of postal addresses.
+lists of residential and postal addresses.
 
 =head1 DEFINITIONS
 
@@ -379,6 +396,10 @@ See L<http://www.upu.int/post_code/en/postal_addressing_systems_member_countries
 for a list of different addressing formats from around the world. And also
 L<http://www.bitboost.com/ref/international-address-formats.html>
 
+=head1 REPOSITORY
+
+L<https://github.com/kimryan/Lingua-EN-AddressParse>
+
 =head1 TO DO
 
 Define grammar for other languages. Hopefully, all that would be needed is
@@ -411,7 +432,7 @@ use Lingua::EN::AddressParse::Grammar;
 use Lingua::EN::NameParse;
 use Parse::RecDescent;
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 #------------------------------------------------------------------------------
 # Create a new instance of an address parsing object. This step is time
